@@ -8,6 +8,7 @@ mod config;
 mod error;
 mod hasher;
 mod spawn_task;
+mod verifier;
 
 /// A type helper for every result returned by this crate.
 pub type Result<T> = std::result::Result<T, Error>;
@@ -15,3 +16,4 @@ pub type Result<T> = std::result::Result<T, Error>;
 pub use config::*;
 pub use error::Error;
 pub use hasher::*;
+pub use verifier::*;
